@@ -16,7 +16,7 @@ MainWindow::MainWindow(QWidget *parent)
 {
     setAttribute(Qt::WA_Maemo5StackedWindow);
     setAttribute(Qt::WA_Maemo5AutoOrientation, true);
-    ytfields = "link(@rel),entry(id,link(@rel,@href),summary,gd:comments,media:group(media:credit/text(),media:description/text(),media:title/text(),media:thumbnail[@yt:name='%1'](@url),yt:duration,yt:uploaded,yt:videoid),gd:rating(@average),yt:statistics(@viewCount),yt:rating)";
+    ytfields = "link(@rel),entry(link(@rel,@href),media:group(media:credit/text(),media:title/text(),media:thumbnail[@yt:name='%1'](@url),yt:duration,yt:uploaded,yt:videoid),gd:rating(@average),yt:statistics(@viewCount),yt:rating)";
     listWidget = new QListWidget(this);
     listWidget->setContextMenuPolicy(Qt::ActionsContextMenu);
     listWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
@@ -82,6 +82,7 @@ void MainWindow::readSettings()
     isAuthenicated = false;
     currentChannelUser = "default";
     rescanDownloaded = true;
+    clearListWidget = true;
 }
 
 void MainWindow::closeEvent(QCloseEvent *event)
@@ -129,6 +130,7 @@ void MainWindow::setupMenus()
     menuBar()->addAction(tr("Settings"), this, SLOT(editSettings()));
     menuBar()->addAction(tr("Recently watched"), this, SLOT(recentWatched()));
     menuBar()->addAction(downloadQueue);
+    menuBar()->addAction(tr("About"), this, SLOT(aboutDlg()));
 
     addToPlaylist = new QAction(tr("Add to playlist"), listWidget);
     connect(addToPlaylist, SIGNAL(triggered()), this, SLOT(on_addToPlaylist()));
@@ -225,6 +227,7 @@ void MainWindow::setupUi()
 {
     /* YouTube Logo */
     ytLabel = new QLabel(this);
+    ytLabel->installEventFilter(this);
     ytLabel->setAlignment(Qt::AlignCenter);
     ytLabel->setPixmap(QPixmap(":/images/yt_logo.png"));
     ytLabel->setStyleSheet("color: grey; font-size: 50px; margin-top: -80px; background-color: rgb(0, 0, 0, 150)");
@@ -319,6 +322,7 @@ void MainWindow::setupUi()
     connect(c, SIGNAL(activated(const QString&)), this, SLOT(searchVideo(const QString&)));
     c->setCaseSensitivity(Qt::CaseInsensitive);
     c->popup()->installEventFilter(this);
+    c->popup()->setContentsMargins(20, 0, 20, 0);
     lineEdit->setCompleter(c);
 }
 
@@ -344,8 +348,8 @@ QStringList MainWindow::scanDownloadFolder()
     QStringList videoIdList;
     videoIdList = QStringList();
     QDir dlDir(settings.value("downloadfolder", "/home/user/MyDocs/.videos").toString());
-    QStringList filenames = dlDir.entryList(QDir::Files | QDir::NoSymLinks, QDir::NoSort);
-    for (int i = 0; i < filenames.size(); ++i){
+    QStringList filenames = dlDir.entryList(QDir::Files | QDir::NoSymLinks, QDir::Time);
+    for (int i = 0; i < filenames.size() && i < 50; ++i){
         if(filenames.at(i).endsWith(".mp4", Qt::CaseSensitive)){
             QString filename = filenames.at(i);
             int sidx = filename.lastIndexOf("(") + 1;
@@ -576,6 +580,7 @@ void MainWindow::editSettings()
         safeSearch = settings.value("safeSearch", "none").toString();
         hqthumb = settings.value("hqthumb", true).toBool();
         net->setUsePreferredServer(settings.value("preferserver", false).toBool());
+        rescanDownloaded = true;
     }
     QStringList rSearch = settings.value("recentSearch", QStringList()).toStringList();
     if(rSearch.isEmpty()){
@@ -591,6 +596,7 @@ void MainWindow::searchVideo(const QString &searchTerm)
     clearListWidget = true;
     net->resetIndex();
     getSearchVideo(searchTerm);
+    setActions("browse");
 }
 
 void MainWindow::getSearchVideo(const QString &searchTerm)
@@ -640,10 +646,12 @@ void MainWindow::feedsButtonActivated(QAbstractButton *button)
         buttonGroup->setExclusive(false);
         button->setChecked(false);
         buttonGroup->setExclusive(true);
+        listWidget->setFocus();
     }
     else {
         if(mainWidget->indexOf(filterListWidget) < 0){
             filterListWidget = new QListWidget(this);
+            filterListWidget->installEventFilter(this);
             mainWidget->addWidget(filterListWidget);
             connect(filterListWidget, SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(filterItemClicked(QListWidgetItem*)));
         }
@@ -658,6 +666,7 @@ void MainWindow::feedsButtonActivated(QAbstractButton *button)
         else {
             filterListWidget->addItems(OptionFilters::getCategoriesList());
         }
+        filterListWidget->setFocus();
     }
     previousButton = button;
     filterGroup->setExclusive(false);
@@ -738,10 +747,9 @@ void MainWindow::itemClicked(QListWidgetItem *item)
 {
     if(!isBusy){
         isBusy = true;
-        VideoDelegateWidget *itemWidget = qobject_cast<VideoDelegateWidget *>(listWidget->itemWidget(item));
-        setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
         setAttribute(Qt::WA_Maemo5LandscapeOrientation, true);
-        orientationChanged();
+        setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
+        VideoDelegateWidget *itemWidget = qobject_cast<VideoDelegateWidget *>(listWidget->itemWidget(item));
         VideoPlayer *video = new VideoPlayer(isAuthenicated, this);
         video->loadVideo(itemWidget->videodata);
         connect(video, SIGNAL(quit()), this, SLOT(restoreOrientation()));
@@ -904,7 +912,8 @@ void MainWindow::on_removeFromFavorite()
 void MainWindow::showSubscription()
 {
     if(mainWidget->indexOf(subscribedListWidget) < 0){
-        subscribedListWidget = new QListWidget;
+        subscribedListWidget = new QListWidget(this);
+        subscribedListWidget->installEventFilter(this);
         subscribedListWidget->setContextMenuPolicy(Qt::ActionsContextMenu);
         subscribedListWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
         QAction *del = new QAction(tr("unsubscribe"), subscribedListWidget);
@@ -915,6 +924,7 @@ void MainWindow::showSubscription()
         updateSubscription("default");
     }
     mainWidget->setCurrentWidget(subscribedListWidget);
+    subscribedListWidget->setFocus();
 }
 
 void MainWindow::updateSubscription(const QString &username)
@@ -924,18 +934,21 @@ void MainWindow::updateSubscription(const QString &username)
     connect(net, SIGNAL(subscriptionsData(const QList< QMap<QString, QString> >&)), this, SLOT(addSubscription(const QList< QMap<QString, QString> >&)));
     net->getUrl(url);
 }
+
 void MainWindow::addSubscription(const QList< QMap<QString, QString> > &subscriptions)
 {
     subscribedListWidget->clear();
     subscribedUrls.clear();
     for (int i =0; i < subscriptions.size(); ++i){
         QMap<QString, QString> subscription = subscriptions.at(i);
-        subscribedListWidget->addItem(QString("%1. %2").arg(i + 1).arg(subscription.value("username")));
-        subscribedUrls.append(subscription.value("username"));
+        QString user = subscription.value("username");
+        subscribedListWidget->addItem(QString("%1. %2").arg(i + 1).arg(user));
+        subscribedUrls.append(user);
         subscribedUrls.append(subscription.value("edit"));
     }
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
     disconnect(net, SIGNAL(subscriptionsData(const QList< QMap<QString, QString> >&)), this, SLOT(addSubscription(const QList< QMap<QString, QString> >&)));
+    subscribedListWidget->setFocus();
 }
 
 void MainWindow::subscribedItemClicked(QListWidgetItem *item)
@@ -994,6 +1007,7 @@ void MainWindow::showPlaylist()
 {
     if(mainWidget->indexOf(playlistListWidget) < 0){
         playlistListWidget = new QListWidget(this);
+        playlistListWidget->installEventFilter(this);
         playlistListWidget->setContextMenuPolicy(Qt::ActionsContextMenu);
         playlistListWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
         QAction *playThisList = new QAction(tr("Play"), playlistListWidget);
@@ -1015,6 +1029,7 @@ void MainWindow::showPlaylist()
         del->setVisible((currentChannelUser == "default"));
     }
     mainWidget->setCurrentWidget(playlistListWidget);
+    playlistListWidget->setFocus();
 }
 
 void MainWindow::updatePlaylist(const QString &username)
@@ -1037,6 +1052,7 @@ void MainWindow::addPlaylist(const QList< QMap<QString, QString> > &playlists)
     }
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
     disconnect(net, SIGNAL(playlistsData(const QList< QMap<QString, QString> >&)), this, SLOT(addPlaylist(const QList< QMap<QString, QString> >&)));
+    playlistListWidget->setFocus();
 }
 
 void MainWindow::playlistItemClicked(QListWidgetItem *item)
@@ -1199,7 +1215,7 @@ void MainWindow::updateSuggestion(const QStringList &list)
 void MainWindow::autoSuggest()
 {
     QString txt = lineEdit->text();
-    if (txt.size() > 2){
+    if (txt.size() > 1){
         QUrl url = QString("http://google.com/complete/search?output=toolbar&q=%1").arg(txt);
         net->getUrl(url);
     }
@@ -1238,5 +1254,17 @@ void MainWindow::errorMessage(const QString &message)
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
     ytLabel->setText(message);
     mainWidget->setCurrentWidget(ytLabel);
+    ytLabel->setFocus();
+}
+
+/* About */
+void MainWindow::aboutDlg() const
+{
+    QMessageBox msgBox;
+    msgBox.setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+    msgBox.setWindowTitle(tr("About"));
+    msgBox.setText( QString(tr( "<img src=':/images/yt_logo.png'/><br><br><font size=2 color='gray'>Version: 0.1.0<br>"
+                                 "Description: YouTube video browser, searcher, and player.</font>")));
+    msgBox.exec();
 }
 
