@@ -318,10 +318,10 @@ void VideoPlayer::loadVideo(const QMap<QString, QString> &video)
         dl->setVisible(true);
     }
     recentWVideos.removeAll(video.value("videoid"));
-    if(recentWVideos.size() == 20){
-        recentWVideos.removeAt(20);
-    }
     recentWVideos.prepend(video.value("videoid"));
+    if(recentWVideos.size() >= 20){
+        recentWVideos.removeAt(20);
+    }   
 }
 
 void VideoPlayer::play()
@@ -347,7 +347,7 @@ void VideoPlayer::loadVideoList(const QString &playlistUrl, const QString &max,
     QUrl url(playlistUrl);
     url.addQueryItem("start-index", QString("%1").arg(start_index));
     url.addQueryItem("max-results", max);
-    url.addQueryItem("fields", "link(@rel),entry(id,link(@rel,@href),summary,gd:comments,media:group(media:credit/text(),media:description/text(),media:title/text(),media:thumbnail[@yt:name='default'](@url),yt:duration,yt:uploaded,yt:videoid),gd:rating(@average),yt:statistics(@viewCount),yt:rating)");
+    url.addQueryItem("fields", "link(@rel),entry(id,link(@rel,@href),media:group(media:credit/text(),media:title/text(),media:thumbnail[@yt:name='default'](@url),yt:videoid),yt:statistics(@viewCount),yt:rating)");
     net->getUrl(url);
 }
 
@@ -386,10 +386,20 @@ void VideoPlayer::itemClicked(QListWidgetItem *item)
 void VideoPlayer::stop()
 {
     mediaObject->stop();
+    mediaObject->deleteLater();
+    net->deleteLater();
     settings.setValue("recentlyWatched", recentWVideos);
     emit quit();
     QTimer::singleShot(0, this, SLOT(close()));
 }
+void VideoPlayer::done()
+{
+    if (!titleLabel->isVisible()){
+        widgetsSwitch();
+    }
+    timer->stop();
+    QTimer::singleShot(0, videoWidget, SLOT(hide()));
+}
 
 void VideoPlayer::mouseReleaseEvent(QMouseEvent*)
 {
@@ -404,14 +414,6 @@ void VideoPlayer::keyPressEvent(QKeyEvent *event)
     QWidget::keyPressEvent(event);
 }
 
-void VideoPlayer::done()
-{
-    if (!titleLabel->isVisible()){
-        widgetsSwitch();
-    }
-    timer->stop();
-}
-
 void VideoPlayer::totalTimeChanged(qint64 time)
 {
     videoDuration = time;
